bundle

package module
v0.0.0-...-d3a19db Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2025 License: BSD-3-Clause Imports: 20 Imported by: 0

README

bundle

Experiment with using go-git to create git bundles.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GoroNumber

func GoroNumber() int

GoroNumber returns the calling goroutine's number.

func IsNil

func IsNil(face interface{}) bool

IsNil uses reflect to to return true iff the face contains a nil pointer, map, array, slice, or channel.

Types

This section is empty.

Jump to