package
module
Version:
v0.0.0-...-d3a19db
Opens a new window with list of versions in this module.
Published: Jul 21, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 20
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
bundle
Experiment with using go-git to create git bundles.
Documentation
¶
GoroNumber returns the calling goroutine's number.
func IsNil(face interface{}) bool
IsNil uses reflect to to return true iff the face
contains a nil pointer, map, array, slice, or channel.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.